.. _updates:

Updates
=======
If you'd like to stay up to date on the community and development of Eve,
there are several options:

GitHub
------
The best way to track the development of Eve is through
`the GitHub repo <https://github.com/nicolaiarocci/eve>`_.

Twitter
-------
I often tweet about new features and releases of Eve. Follow `@nicolaiarocci
<https://twitter.com/nicolaiarocci>`_ for updates.

IRC
---
The official Freenode channel for Eve is `#evehq
<irc://irc.freenode.net/evehq>`_

